##  Data Synchronization
How to perform synchronization between SAP LeanIX and ServiceNow and vice versa? What should be the master (source) system?
According to best practices, applications and business capabilities should be mastered in SAP LeanIX. The infrastructure landscape (IT components and tech categories) should be mastered in ServiceNow. ServiceNow has discovery and asset management capabilities. Synchronization between the systems occurs daily. You can also synchronize data manually. Data is updated in case of any modifications.
At first synchronization, SAP LeanIX captures the ServiceNow sys_id field of existing business applications that match on the name field. What are best practices for cases when both systems are already established with data that may conflict?
It's recommended to maintain consistent naming across both systems to ensure uniformity in enterprise language. If discrepancies exist, adjust the item names. If you’re experiencing problems when changing names, please [submit a ticket![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fwww.leanix.net%2Fsupport "https://www.leanix.net/support") to SAP LeanIX Support. If you're an SAP customer, submit a request from the [SAP for Me![Information published on SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/sap_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fme.sap.com%2F "https://me.sap.com/") portal.
